import { Awaitable } from '@antfu/utils';
import { TransformResult, ViteDevServer } from 'vite';
import { F as File, l as Task, T as TaskResultPack, R as ResolvedConfig, t as SnapshotSummary, S as SnapshotResult, n as Reporter } from './options-654578ef';

declare class StateManager {
    filesMap: Record<string, File>;
    idMap: Record<string, Task>;
    taskFileMap: WeakMap<Task, File>;
    getFiles(keys?: string[]): File[];
    collectFiles(files: File[]): void;
    updateId(task: Task): void;
    updateTasks(packs: TaskResultPack[]): void;
}

declare class SnapshotManager {
    config: ResolvedConfig;
    summary: SnapshotSummary;
    constructor(config: ResolvedConfig);
    clear(): void;
    add(result: SnapshotResult): void;
}

interface ModuleCache {
    promise?: Promise<any>;
    exports?: any;
    transformResult?: TransformResult;
}
interface EnvironmentReturn {
    teardown: (global: any) => Awaitable<void>;
}
interface Environment {
    name: string;
    setup(global: any): Awaitable<EnvironmentReturn>;
}
interface VitestContext {
    config: ResolvedConfig;
    server: ViteDevServer;
    state: StateManager;
    snapshot: SnapshotManager;
    reporter: Reporter;
}

export { EnvironmentReturn as E, ModuleCache as M, VitestContext as V, Environment as a };
